@@ -9,7 +9,7 @@
     'name_es_ES': 'País',
     'name_fr_FR': 'Pays',
     'name_ru_RU': 'Страны',
-    'version' : '2.0.1',
+    'version' : '2.2.1',
     'author' : 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -25,12 +25,13 @@
         'country.xml',
     ],
     'translation': [
-        'bg_BG.csv',
-        'cs_CZ.csv',
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
-        'ru_RU.csv',
+        'locale/bg_BG.po',
+        'locale/cs_CZ.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
    ],
 }
